@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: client.c,v 1.56 2006/05/12 19:06:47 evertonm Exp $ */
+/* $Id: client.c,v 1.59 2006/06/02 14:24:38 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -137,6 +137,7 @@ static void *on_tcp_write(oop_source *src, int sd,
   nepim_pipe_t *pipe = user;
   nepim_session_t *session = &pipe->session;
   unsigned old_seed;
+  int to_write;
 
   assert(event == OOP_WRITE);
   assert(sd == pipe->sd);
@@ -145,11 +146,15 @@ static void *on_tcp_write(oop_source *src, int sd,
 
   assert(sizeof(buf) == nepim_global.tcp_write_size);
 
+  to_write = nepim_write_sweep(session);
+  assert(to_write >= 0);
+  assert(to_write <= nepim_global.tcp_write_size);
+
   old_seed = session->seed;
   /* modifies 'session->seed' */
-  fill_packet_data(session, buf, 0, nepim_global.tcp_write_size);
+  fill_packet_data(session, buf, 0, to_write);
 
-  wr = write(sd, buf, nepim_global.tcp_write_size);
+  wr = write(sd, buf, to_write);
   if (wr < 0) {
     session->seed = old_seed;   /* rewind seed */
     switch (errno) {
@@ -173,7 +178,7 @@ static void *on_tcp_write(oop_source *src, int sd,
 
     return OOP_CONTINUE;
   }
-  if (wr < nepim_global.tcp_write_size) {
+  if (wr < to_write) {
       /* rewind seed to use exactly 'wr' bytes */
       session->seed = old_seed;
       /* modifies 'session->seed' */
@@ -181,7 +186,8 @@ static void *on_tcp_write(oop_source *src, int sd,
   }
 
   assert(wr >= 0);
-  assert(wr <= sizeof(buf));
+  assert(wr <= to_write);
+  assert(to_write <= (sizeof buf));
 
   nepim_session_write_add(session, wr + session->overhead);
 
@@ -196,6 +202,7 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
   int full_wr; /* payload plus overhead */
   nepim_pipe_t *pipe = user;
   nepim_session_t *session = &pipe->session;
+  int sweep_write;
   int to_write;
   unsigned old_seed;
 
@@ -225,16 +232,20 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
   }
 #endif /* NDEBUG */
 
+  sweep_write = nepim_write_sweep(session);
+  assert(sweep_write >= 0);
+  assert(sweep_write <= (sizeof buf));
+
   if (session->rate_remaining > 0)
     to_write = NEPIM_RANGE(session->rate_remaining - session->overhead,
 			   0,
-			   sizeof(buf));
+			   sweep_write);
   else
-    to_write = sizeof(buf);
+    to_write = sweep_write;
 
   assert(to_write >= 0);
-  assert(to_write <= sizeof(buf));
-  
+  assert(to_write <= sweep_write);
+
   old_seed = session->seed;
   /* modifies 'session->seed' */
   fill_packet_data(session, buf, 0, to_write);
@@ -273,6 +284,7 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
   assert(wr >= 0);
   assert(wr <= sizeof(buf));
   assert(wr <= to_write);
+  assert(to_write <= sweep_write);
 
   full_wr = wr + session->overhead;
 
@@ -430,6 +442,10 @@ static int greet(int sd)
   opt.socket_keepalive        = nepim_global.socket_keepalive;
   opt.nagle                   = nepim_global.nagle;
   opt.overhead                = nepim_global.tcp_overhead;
+  opt.sweep_random            = nepim_global.sweep_random;
+  opt.sweep_step              = nepim_global.sweep_step;
+  opt.write_floor             = nepim_global.server_write_floor;
+  opt.write_ceil              = nepim_global.server_write_ceil;
 
   if (nepim_global.password) {
     opt.password_buf      = nepim_global.password;
@@ -932,6 +948,10 @@ static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
       opt.fill_byte               = nepim_global.fill_byte;
       opt.pause_duration          = nepim_global.pause_duration;
       opt.overhead                = nepim_global.tcp_overhead;
+      opt.sweep_random            = nepim_global.sweep_random;
+      opt.sweep_step              = nepim_global.sweep_step;
+      opt.write_floor             = nepim_global.write_floor;
+      opt.write_ceil              = nepim_global.write_ceil;
 
       nepim_pipe_set_add(&pipes, sd, ai->ai_addr, ai->ai_addrlen, &opt);
     }
@@ -966,7 +986,7 @@ static void parse_hosts(const char *host_list)
   /* scan host_list */
   for (j = 0; j < size; ++j) {
     char hostname[100];
-    const char *portname;
+    char *portname;
 
     /* get hostname */
     if (addr_list_get(host_list, j, hostname, sizeof(hostname))) {
