@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.c,v 1.64 2006/05/23 20:38:41 evertonm Exp $ */
+/* $Id: common.c,v 1.68 2006/06/02 13:18:32 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -47,7 +47,7 @@ static int line = 0;
 
 const char *nepim_version()
 {
-  return "0.27";
+  return "0.28";
 }
 
 static void header(FILE *out, int ident, int udp)
@@ -89,7 +89,7 @@ void nepim_pipe_stat(FILE *out, struct timeval now,
   char buf[100];
   int pr;
 
-  pr = snprintf(buf, sizeof buf, "%3d %4s %5ld",
+  pr = snprintf(buf, sizeof buf, "%3d %3s %5ld",
 		sd, label, sec_duration - (now.tv_sec - sec_start));
 
   header(out, pr, 0 /* udp=false */);
@@ -411,7 +411,7 @@ struct sockaddr *nepim_addrlist_findfirst(int socktype, int proto,
 
   for (i = 0; i < size; ++i) {
     char hostname[100];
-    const char *portname;
+    char *portname;
     struct addrinfo hints;
     struct addrinfo *ai_res;
     struct addrinfo *ai;
@@ -466,4 +466,3 @@ struct sockaddr *nepim_addrlist_findfirst(int socktype, int proto,
 
   return 0;
 }
-
