@@ -82,8 +82,14 @@ struct nepim_global_t {
   int           tcp_keepalive_require;    /* boolean, receivers */
   int           tcp_keepalive_must_send;  /* boolean, non-senders */
   int           nagle; /* client, boolean, -1 is don't change */
-  int           udp_overhead; /* bytes */
-  int           tcp_overhead; /* bytes */
+  int           udp_overhead;       /* bytes */
+  int           tcp_overhead;       /* bytes */
+  int           sweep_random;       /* boolean */
+  int           sweep_step;         /* bytes */
+  int           write_floor;        /* bytes */
+  int           write_ceil;         /* bytes */
+  int           server_write_floor; /* bytes */
+  int           server_write_ceil;  /* bytes */
 
   oop_source_sys *oop_sys;
   oop_source     *oop_src;
@@ -91,4 +97,12 @@ struct nepim_global_t {
 
 extern nepim_global_t nepim_global;
 
+void nepim_conf_write_sweep_auto(int is_udp,
+				 int *write_floor,
+				 int *write_ceil);
+
+void nepim_conf_write_sweep_fit(int is_udp,
+				int *write_floor,
+				int *write_ceil);
+
 #endif /* NEPIM_CONF_H */
