@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: greet.h,v 1.13 2006/04/23 06:33:46 evertonm Exp $ */
+/* $Id: greet.h,v 1.16 2006/06/02 14:24:38 evertonm Exp $ */
 
 #ifndef NEPIM_GREET_H
 #define NEPIM_GREET_H
@@ -42,6 +42,10 @@ struct nepim_greet_t {
   int           socket_keepalive;
   int           nagle;
   int           overhead;
+  int           sweep_random;
+  int           sweep_step;
+  int           write_floor;
+  int           write_ceil;
   char          *password_buf;
   int           password_buf_size;
 };
