@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.67 2006/05/12 19:06:47 evertonm Exp $ */
+/* $Id: server.c,v 1.71 2006/06/02 18:23:09 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -123,6 +123,7 @@ static void *on_tcp_write(oop_source *src, int sd,
   nepim_pipe_t *pipe = user;
   nepim_session_t *session = &pipe->session;
   unsigned old_seed;
+  int to_write;
 
   assert(event == OOP_WRITE);
   assert(sd == pipe->sd);
@@ -131,11 +132,15 @@ static void *on_tcp_write(oop_source *src, int sd,
 
   assert(sizeof(buf) == nepim_global.tcp_write_size);
 
+  to_write = nepim_write_sweep(session);
+  assert(to_write >= 0);
+  assert(to_write <= nepim_global.tcp_write_size);
+
   old_seed = session->seed;
   /* modifies 'session->seed' */
-  fill_packet_data(session, buf, 0, nepim_global.tcp_write_size);
+  fill_packet_data(session, buf, 0, to_write);
 
-  wr = write(sd, buf, nepim_global.tcp_write_size);
+  wr = write(sd, buf, to_write);
   if (wr < 0) {
     session->seed = old_seed;   /* rewind seed */
     switch (errno) {
@@ -159,7 +164,7 @@ static void *on_tcp_write(oop_source *src, int sd,
 
     return OOP_CONTINUE;
   }
-  if (wr < nepim_global.tcp_write_size) {
+  if (wr < to_write) {
       /* rewind seed to use exactly 'wr' bytes */
       session->seed = old_seed;
       /* modifies 'session->seed' */
@@ -167,7 +172,8 @@ static void *on_tcp_write(oop_source *src, int sd,
   }
 
   assert(wr >= 0);
-  assert(wr <= sizeof(buf));
+  assert(wr <= to_write);
+  assert(to_write <= (sizeof buf));
 
   nepim_session_write_add(session, wr + session->overhead);
 
@@ -182,6 +188,7 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
   int full_wr; /* payload plus overhead */
   nepim_pipe_t *pipe = user;
   nepim_session_t *session = &pipe->session;
+  int sweep_write;
   int to_write;
   unsigned old_seed;
 
@@ -211,15 +218,19 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
   }
 #endif /* NDEBUG */
 
+  sweep_write = nepim_write_sweep(session);
+  assert(sweep_write >= 0);
+  assert(sweep_write <= (sizeof buf));
+
   if (session->rate_remaining > 0)
     to_write = NEPIM_RANGE(session->rate_remaining - session->overhead,
 			   0,
-			   sizeof(buf));
+			   sweep_write);
   else
-    to_write = sizeof(buf);
+    to_write = sweep_write;
 
   assert(to_write >= 0);
-  assert(to_write <= sizeof(buf));
+  assert(to_write <= sweep_write);
 
   old_seed = session->seed;
   /* modifies 'session->seed' */
@@ -259,6 +270,7 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
   assert(wr >= 0);
   assert(wr <= sizeof(buf));
   assert(wr <= to_write);
+  assert(to_write <= sweep_write);
 
   full_wr = wr + session->overhead;
 
@@ -413,15 +425,31 @@ static int parse_greetings(int sd,
           "%d: send=%d bit_rate=%lld pkt_rate=%d "
           "interval=%d duration=%d delay=%ld ka_send=%d ka_req=%d seed=0x%08x "
           "verify_data=%d random_fill=%d fill_byte=0x%02x pause_duration=%d "
-          "sock_ka=%d nagle=%d overhead=%d password=%s\n", 
+          "sock_ka=%d nagle=%d overhead=%d "
+	  "sweep_random=%d sweep_step=%d write_floor=%d write_ceil=%d "
+	  "password=%s\n", 
           sd, opt.must_send, opt.bit_rate, opt.pkt_rate,
           opt.stat_interval, opt.test_duration, 
           opt.write_delay, opt.keepalive_must_send,
           opt.keepalive_require, opt.seed,
           opt.verify_data, opt.random_fill, opt.fill_byte, opt.pause_duration,
 	  opt.socket_keepalive, opt.nagle, opt.overhead,
+	  opt.sweep_random, opt.sweep_step, opt.write_floor, opt.write_ceil,
           password_buf);
 
+  nepim_conf_write_sweep_auto(0 /* udp=false */,
+			      &opt.write_floor,
+			      &opt.write_ceil);
+
+  nepim_conf_write_sweep_fit(0 /* udp=false */,
+			     &opt.write_floor,
+			     &opt.write_ceil);
+
+  fprintf(stderr, 
+          "%d: sweep write: floor=%d ceil=%d\n",
+	  sd,
+	  opt.write_floor, opt.write_ceil);
+
   if (nepim_global.password)
     if (strcmp(nepim_global.password, password_buf)) {
       fprintf(stderr, "%d: bad client password=%s\n",
@@ -1060,7 +1088,7 @@ static void parse_listeners(const char *list, int *udp, int *tcp, int join)
 
   for (i = 0; i < size; ++i) {
     char buf[100];
-    const char *portname;
+    char *portname;
 
     if (addr_list_get(list, i, buf, sizeof(buf))) {
       fprintf(stderr, 
