@@ -18,8 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.68 2006/05/12 19:06:47 evertonm Exp $ */
-
+/* $Id: udp_client.c,v 1.71 2006/06/02 14:24:38 evertonm Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -410,6 +409,10 @@ static int slot_greet_write(nepim_slot_t *slot)
   opt.pause_duration          = nepim_global.pause_duration;
   opt.socket_keepalive        = nepim_global.socket_keepalive;
   opt.overhead                = nepim_global.udp_overhead;
+  opt.sweep_random            = nepim_global.sweep_random;
+  opt.sweep_step              = nepim_global.sweep_step;
+  opt.write_floor             = nepim_global.server_write_floor;
+  opt.write_ceil              = nepim_global.server_write_ceil;
 
   if (nepim_global.password) {
     opt.password_buf      = nepim_global.password;
@@ -459,10 +462,12 @@ static int slot_greet_write(nepim_slot_t *slot)
           UDP_HEADER_LEN, pr, write_len, wr);
 #endif
 
-  if (wr != write_len)
+  if (wr != write_len) {
+    nepim_usock_write_good_partial(&udp_tab, slot->udp_sd);
     return -4;
+  }
 
-  nepim_usock_write_good(&udp_tab, slot->udp_sd);
+  nepim_usock_write_good_full(&udp_tab, slot->udp_sd);
 
   return 0;
 }
@@ -671,6 +676,7 @@ static void udp_write_rate(nepim_slot_t *slot)
   int wr;                   /* payload only */
   int full_wr;              /* payload plus overhead */
   nepim_session_t *session;
+  int sweep_write;
   int to_write;
   int sd;
 
@@ -703,16 +709,20 @@ static void udp_write_rate(nepim_slot_t *slot)
   }
 #endif /* NDEBUG */
 
+  sweep_write = nepim_write_sweep(session);
+  assert(sweep_write >= UDP_HEADER_LEN);
+  assert(sweep_write <= (sizeof buf));
+
   if (session->rate_remaining > 0)
     to_write = NEPIM_RANGE(session->rate_remaining - session->overhead, 
                            UDP_HEADER_LEN, 
-                           sizeof(buf));
+                           sweep_write);
   else
-    to_write = sizeof(buf);
+    to_write = sweep_write;
 
   assert(to_write >= 0);
   assert(to_write >= UDP_HEADER_LEN);
-  assert(to_write <= sizeof(buf));
+  assert(to_write <= sweep_write);
 
   wr = nepim_slot_buf_write(slot, buf, to_write, UDP_TYPE_DATA);
   if (wr < 0) {
@@ -752,7 +762,10 @@ static void udp_write_rate(nepim_slot_t *slot)
   assert(wr >= 0);
   assert(wr <= to_write);
 
-  nepim_usock_write_good(&udp_tab, slot->udp_sd);
+  if (wr == to_write)
+    nepim_usock_write_good_full(&udp_tab, slot->udp_sd);
+  else
+    nepim_usock_write_good_partial(&udp_tab, slot->udp_sd);
 
   full_wr = wr + session->overhead;
 
@@ -784,6 +797,7 @@ static void udp_write_full(nepim_slot_t *slot)
   int wr;                   /* payload only */
   nepim_session_t *session;
   int sd;
+  int to_write;
 
   assert(nepim_global.udp_write_size == sizeof(buf));
   assert(slot);
@@ -795,7 +809,11 @@ static void udp_write_full(nepim_slot_t *slot)
   assert(session->max_bit_rate < 1);
   assert(session->max_pkt_rate < 1);
 
-  wr = nepim_slot_buf_write(slot, buf, sizeof(buf), UDP_TYPE_DATA);
+  to_write = nepim_write_sweep(session);
+  assert(to_write >= UDP_HEADER_LEN);
+  assert(to_write <= (sizeof buf));
+
+  wr = nepim_slot_buf_write(slot, buf, to_write, UDP_TYPE_DATA);
   if (wr < 0) {
     switch (errno) {
     case EINTR:
@@ -831,9 +849,13 @@ static void udp_write_full(nepim_slot_t *slot)
   }
 
   assert(wr >= 0);
-  assert(wr <= sizeof(buf));
+  assert(wr <= to_write);
+  assert(to_write <= sizeof(buf));
 
-  nepim_usock_write_good(&udp_tab, sd);
+  if (wr == to_write)
+    nepim_usock_write_good_full(&udp_tab, sd);
+  else
+    nepim_usock_write_good_partial(&udp_tab, sd);
 
   nepim_session_write_add(session, wr + session->overhead);
 }
@@ -1327,7 +1349,7 @@ static void parse_hosts(const char *host_list)
   /* scan host_list */
   for (j = 0; j < size; ++j) {
     char hostname[100];
-    const char *portname;
+    char *portname;
 
     /* get hostname */
     if (addr_list_get(host_list, j, hostname, sizeof(hostname))) {
@@ -1377,6 +1399,10 @@ static void parse_hosts(const char *host_list)
       opt.fill_byte               = nepim_global.fill_byte;
       opt.pause_duration          = nepim_global.pause_duration;
       opt.overhead                = nepim_global.udp_overhead;
+      opt.sweep_random            = nepim_global.sweep_random;
+      opt.sweep_step              = nepim_global.sweep_step;
+      opt.write_floor             = nepim_global.write_floor;
+      opt.write_ceil              = nepim_global.write_ceil;
       
       /* create UDP slots */
       for (i = 0; i < nepim_global.pipes; ++i) {
