@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.93 2006/05/23 20:38:41 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.96 2006/06/02 14:24:38 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -392,6 +392,7 @@ static void udp_write_rate(nepim_slot_t *slot)
   int wr;                   /* payload only */
   int full_wr;              /* payload plus overhead */
   nepim_session_t *session;
+  int sweep_write;
   int to_write;
   int sd;
 
@@ -423,16 +424,20 @@ static void udp_write_rate(nepim_slot_t *slot)
   }
 #endif /* NDEBUG */
 
+  sweep_write = nepim_write_sweep(session);
+  assert(sweep_write >= UDP_HEADER_LEN);
+  assert(sweep_write <= (sizeof buf));
+
   if (session->rate_remaining > 0)
     to_write = NEPIM_RANGE(session->rate_remaining - session->overhead, 
 			   UDP_HEADER_LEN, 
-			   sizeof(buf));
+			   sweep_write);
   else
-    to_write = sizeof(buf);
+    to_write = sweep_write;
 
   assert(to_write >= 0);
   assert(to_write >= UDP_HEADER_LEN);
-  assert(to_write <= sizeof(buf));
+  assert(to_write <= sweep_write);
 
   wr = nepim_slot_buf_sendto(slot, buf, to_write, UDP_TYPE_DATA);
   if (wr < 0) {
@@ -462,7 +467,10 @@ static void udp_write_rate(nepim_slot_t *slot)
   assert(wr >= 0);
   assert(wr <= to_write);
 
-  nepim_usock_write_good(&udp_tab, sd);
+  if (wr == to_write)
+    nepim_usock_write_good_full(&udp_tab, sd);
+  else
+    nepim_usock_write_good_partial(&udp_tab, sd);
 
   full_wr = wr + session->overhead;
 
@@ -494,6 +502,7 @@ static void udp_write_full(nepim_slot_t *slot)
   int wr;
   nepim_session_t *session;
   int sd;
+  int to_write;
 
   assert(nepim_global.udp_write_size == sizeof(buf));
   assert(slot);
@@ -504,7 +513,11 @@ static void udp_write_full(nepim_slot_t *slot)
   assert(session->max_bit_rate < 1);
   assert(session->max_pkt_rate < 1);
 
-  wr = nepim_slot_buf_sendto(slot, buf, sizeof(buf), UDP_TYPE_DATA);
+  to_write = nepim_write_sweep(session);
+  assert(to_write >= UDP_HEADER_LEN);
+  assert(to_write <= (sizeof buf));
+
+  wr = nepim_slot_buf_sendto(slot, buf, to_write, UDP_TYPE_DATA);
   if (wr < 0) {
     switch (errno) {
     case EINTR:
@@ -533,9 +546,13 @@ static void udp_write_full(nepim_slot_t *slot)
   }
 
   assert(wr >= 0);
-  assert(wr <= sizeof(buf));
+  assert(wr <= to_write);
+  assert(to_write <= sizeof(buf));
 
-  nepim_usock_write_good(&udp_tab, sd);
+  if (wr == to_write)
+    nepim_usock_write_good_full(&udp_tab, sd);
+  else
+    nepim_usock_write_good_partial(&udp_tab, sd);
 
   nepim_session_write_add(session, wr + session->overhead);
 }
@@ -771,7 +788,9 @@ static int parse_greetings(nepim_greet_t *opt,
 	  "%d %d-%d: UDP from (%s,%d): send=%d bps=%lld pps=%d "
 	  "interval=%d duration=%d delay=%ld ka_send=%d ka_req=%d seed=0x%08x "
 	  "verify_data=%d random_fill=%d fill_byte=0x%02x pause_duration=%d "
-	  "sock_ka=%d overhead=%d password=%s\n", 
+	  "sock_ka=%d overhead=%d "
+	  "sweep_random=%d sweep_step=%d write_floor=%d write_ceil=%d "
+	  "password=%s\n", 
 	  sd, 
 	  local_slot, remote_slot,
 	  peer,
@@ -783,8 +802,23 @@ static int parse_greetings(nepim_greet_t *opt,
 	  opt->verify_data, opt->random_fill, opt->fill_byte,
 	  opt->pause_duration, opt->socket_keepalive,
 	  opt->overhead,
+	  opt->sweep_random, opt->sweep_step, opt->write_floor, opt->write_ceil,
 	  password_buf);
 
+  nepim_conf_write_sweep_auto(1 /* udp=true */,
+			      &(opt->write_floor),
+			      &(opt->write_ceil));
+
+  nepim_conf_write_sweep_fit(1 /* udp=true */,
+			     &(opt->write_floor),
+			     &(opt->write_ceil));
+
+  fprintf(stderr, 
+          "%d %d-%d: sweep write: floor=%d ceil=%d\n",
+	  sd, 
+	  local_slot, remote_slot,
+	  opt->write_floor, opt->write_ceil);
+
   if (nepim_global.tcpwrap) {
     if (!nepim_hosts_ctl(nepim_global.tcpwrap,
 			 nepim_global.prog_name,
